@@ -38,11 +38,34 @@ class StructureDivision(Base):
         return self.name_ru
 
 
+class PersonnelType(Base):
+    """
+    Тип сотрудника
+    """
+    __tablename__ = 'univer_type_personal_1c'
+
+    # Идентификатор
+    id = Column('type_personal_id', Integer, primary_key=True)
+
+    # Наименование
+    name_ru = Column('type_personal_name_ru', String(100))
+    name_kz = Column('type_personal_name_kz', String(100))
+    name_en = Column('type_personal_name_en', String(100))
+
+    # Статус
+    status = Column(Integer)
+
+    def __repr__(self):
+        return '<PersonnelType {} (id={} status={})'.format(self, self.id, self.status)
+
+    def __str__(self):
+        return self.name_ru
+
+
 class PersonnelStructureDivisionLink(Base):
     """
-    Модель "Ссылка персонала с подразделением"
+    Связь между сотрудником и подразделением
     """
-
     __tablename__ = 'univer_personal_struct_pos_link_1c'
 
     # Идентификатор
@@ -66,6 +89,14 @@ class PersonnelStructureDivisionLink(Base):
         'univer_personal_position_1c.personal_position_id'))
     personnel_position = relationship('PersonnelPosition')
 
+    # Тип сотрудника
+    personnel_type_id = Column('type_id', ForeignKey(
+        'univer_type_personal_1c.type_personal_id'))
+    personnel_type = relationship('PersonnelType')
+
+    # Ставка
+    rate = Column('personal_rate', Float)
+
     def __repr__(self):
         return '<PersonnelStructureDivisionLink {}>'.format(self)
 
