@@ -28,5 +28,7 @@ class TestAdviser(unittest.TestCase):
         adviser = session.query(Adviser).filter(Adviser.status == 1).first()
         print(f'adviser: {adviser}')
 
-        for adviser_student in adviser.students:
-            print(f'student: {adviser_student.student}')
+        total = adviser.students.count()
+
+        for index, adviser_student in enumerate(adviser.students):
+            print(f'[{index + 1}/{total}] student: {adviser_student.student}')
